==> cabal-install-3.8.1.0-155-riscv64.pkg.tar.zst: usr/share/haskell/register/cabal-install.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install
version:              3.8.1.0
visibility:           public
id:                   cabal-install-3.8.1.0-KvzP6ldlR2tFBZ2BeoYl6K
key:                  cabal-install-3.8.1.0-KvzP6ldlR2tFBZ2BeoYl6K
license:              BSD-3-Clause
copyright:            2003-2022, Cabal Development Team
maintainer:           Cabal Development Team <cabal-devel@haskell.org>
author:               Cabal Development Team (see AUTHORS file)
homepage:             http://www.haskell.org/cabal/
synopsis:             The command-line interface for Cabal and Hackage.
description:
    The \'\''cabal\'\'' command-line program simplifies the process of managing
    Haskell software by automating the fetching, configuration, compilation
    and installation of Haskell libraries and programs.

category:             Distribution
abi:                  bf8542fb71acb2e753d8101bedf5b8f0
exposed:              True
exposed-modules:
    Distribution.Client.BuildReports.Anonymous
    Distribution.Client.BuildReports.Lens
    Distribution.Client.BuildReports.Storage
    Distribution.Client.BuildReports.Types
    Distribution.Client.BuildReports.Upload Distribution.Client.Check
    Distribution.Client.CmdBench Distribution.Client.CmdBuild
    Distribution.Client.CmdClean Distribution.Client.CmdConfigure
    Distribution.Client.CmdErrorMessages Distribution.Client.CmdExec
    Distribution.Client.CmdFreeze Distribution.Client.CmdHaddock
    Distribution.Client.CmdInstall
    Distribution.Client.CmdInstall.ClientInstallFlags
    Distribution.Client.CmdInstall.ClientInstallTargetSelector
    Distribution.Client.CmdLegacy Distribution.Client.CmdListBin
    Distribution.Client.CmdOutdated Distribution.Client.CmdRepl
    Distribution.Client.CmdRun Distribution.Client.CmdSdist
    Distribution.Client.CmdTest Distribution.Client.CmdUpdate
    Distribution.Client.Compat.Directory
    Distribution.Client.Compat.ExecutablePath
    Distribution.Client.Compat.Orphans
    Distribution.Client.Compat.Prelude
    Distribution.Client.Compat.Process
    Distribution.Client.Compat.Semaphore Distribution.Client.Config
    Distribution.Client.Configure Distribution.Client.Dependency
    Distribution.Client.Dependency.Types
    Distribution.Client.DistDirLayout Distribution.Client.Fetch
    Distribution.Client.FetchUtils Distribution.Client.FileMonitor
    Distribution.Client.Freeze Distribution.Client.GZipUtils
    Distribution.Client.GenBounds Distribution.Client.Get
    Distribution.Client.Glob Distribution.Client.GlobalFlags
    Distribution.Client.Haddock Distribution.Client.HashValue
    Distribution.Client.HttpUtils Distribution.Client.IndexUtils
    Distribution.Client.IndexUtils.ActiveRepos
    Distribution.Client.IndexUtils.IndexState
    Distribution.Client.IndexUtils.Timestamp Distribution.Client.Init
    Distribution.Client.Init.Defaults
    Distribution.Client.Init.FileCreators
    Distribution.Client.Init.FlagExtractors
    Distribution.Client.Init.Format
    Distribution.Client.Init.Interactive.Command
    Distribution.Client.Init.Licenses
    Distribution.Client.Init.NonInteractive.Command
    Distribution.Client.Init.NonInteractive.Heuristics
    Distribution.Client.Init.Prompt Distribution.Client.Init.Simple
    Distribution.Client.Init.Types Distribution.Client.Init.Utils
    Distribution.Client.Install Distribution.Client.InstallPlan
    Distribution.Client.InstallSymlink Distribution.Client.JobControl
    Distribution.Client.List Distribution.Client.Manpage
    Distribution.Client.ManpageFlags Distribution.Client.Nix
    Distribution.Client.NixStyleOptions Distribution.Client.PackageHash
    Distribution.Client.ParseUtils Distribution.Client.ProjectBuilding
    Distribution.Client.ProjectBuilding.Types
    Distribution.Client.ProjectConfig
    Distribution.Client.ProjectConfig.Legacy
    Distribution.Client.ProjectConfig.Types
    Distribution.Client.ProjectFlags
    Distribution.Client.ProjectOrchestration
    Distribution.Client.ProjectPlanOutput
    Distribution.Client.ProjectPlanning
    Distribution.Client.ProjectPlanning.Types
    Distribution.Client.RebuildMonad Distribution.Client.Reconfigure
    Distribution.Client.Run Distribution.Client.Sandbox
    Distribution.Client.Sandbox.PackageEnvironment
    Distribution.Client.SavedFlags Distribution.Client.ScriptUtils
    Distribution.Client.Security.DNS Distribution.Client.Security.HTTP
    Distribution.Client.Setup Distribution.Client.SetupWrapper
    Distribution.Client.SolverInstallPlan
    Distribution.Client.SourceFiles Distribution.Client.SrcDist
    Distribution.Client.Store Distribution.Client.Tar
    Distribution.Client.TargetProblem
    Distribution.Client.TargetSelector Distribution.Client.Targets
    Distribution.Client.Types Distribution.Client.Types.AllowNewer
    Distribution.Client.Types.BuildResults
    Distribution.Client.Types.ConfiguredId
    Distribution.Client.Types.ConfiguredPackage
    Distribution.Client.Types.Credentials
    Distribution.Client.Types.InstallMethod
    Distribution.Client.Types.OverwritePolicy
    Distribution.Client.Types.PackageLocation
    Distribution.Client.Types.PackageSpecifier
    Distribution.Client.Types.ReadyPackage
    Distribution.Client.Types.Repo Distribution.Client.Types.RepoName
    Distribution.Client.Types.SourcePackageDb
    Distribution.Client.Types.SourceRepo
    Distribution.Client.Types.WriteGhcEnvironmentFilesPolicy
    Distribution.Client.Upload Distribution.Client.Utils
    Distribution.Client.Utils.Json Distribution.Client.Utils.Parsec
    Distribution.Client.VCS Distribution.Client.Version
    Distribution.Client.Win32SelfUpgrade
    Distribution.Deprecated.ParseUtils Distribution.Deprecated.ReadP
    Distribution.Deprecated.ViewAsFieldDescr

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cabal-install-3.8.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cabal-install-3.8.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cabal-install-3.8.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cabal-install
hs-libraries:         HScabal-install-3.8.1.0-KvzP6ldlR2tFBZ2BeoYl6K
depends:
    Cabal-3.8.1.0 Cabal-syntax-3.8.1.0
    HTTP-4000.4.1-I2SHq0OXREm3IzlxzjgUek array-0.5.4.0
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0 base-4.17.2.1
    base16-bytestring-1.0.2.0-1Uz6oHjhPf9KewF5fWee2u binary-0.8.9.1
    bytestring-0.11.5.3
    cabal-install-solver-3.8.1.0-tBuMrgBjy2E0BakKQfROg containers-0.6.7
    cryptohash-sha256-0.11.102.1-9lKR7BNsiyq7t2yDe4jjeV
    directory-1.3.7.1 echo-0.1.4-HrG6UGs9bUNIRHTRpjaAQ
    edit-distance-0.2.2.1-LeN0XmUdpHn9RcdF7Kjyav exceptions-0.10.5
    filepath-1.4.2.2 hackage-security-0.6.3.2-CHDf3RgkDvnA7KEagrQnJe
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    lukko-0.1.2-Ca4c2SwPaleHGXLDJZtEU2 mtl-2.2.2
    network-uri-2.6.4.2-DVBcu05aYxxCjTvpzOd17v parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.18.0
    random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT
    regex-base-0.94.0.3-4CB0YhYwj75B1BjBDOnQyh
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9
    resolv-0.2.0.3-HtJfk0XMqjqE4d0ilnegP2
    safe-exceptions-0.1.7.4-E2jhex6cl0w6t2rEagsyOt stm-2.5.1.0
    tar-0.5.1.1-AZjsJHqgsjD6kJ02jOCOvu text-2.0.2 time-1.12.2
    unix-2.7.3 zlib-0.7.0.0-8ZqFqGsvFQB8ur6Sh8fLj0

haddock-interfaces:   /usr/share/doc/cabal-install/html/cabal-install.haddock
haddock-html:         /usr/share/doc/cabal-install/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> cabal-install-3.10.3.0-8-riscv64.pkg.tar.zst: usr/share/haskell/register/cabal-install.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install
version:              3.10.3.0
visibility:           public
id:                   cabal-install-3.10.3.0-8vILTNaREgJ9c93t1WS3Ih
key:                  cabal-install-3.10.3.0-8vILTNaREgJ9c93t1WS3Ih
license:              BSD-3-Clause
copyright:            2003-2023, Cabal Development Team
maintainer:           Cabal Development Team <cabal-devel@haskell.org>
author:               Cabal Development Team (see AUTHORS file)
homepage:             http://www.haskell.org/cabal/
synopsis:             The command-line interface for Cabal and Hackage.
description:
    The \'\''cabal\'\'' command-line program simplifies the process of managing
    Haskell software by automating the fetching, configuration, compilation
    and installation of Haskell libraries and programs.

category:             Distribution
abi:                  80072ffcf2aeb2f1aa49bea6b07dcb1e
exposed:              True
exposed-modules:
    Distribution.Client.BuildReports.Anonymous
    Distribution.Client.BuildReports.Lens
    Distribution.Client.BuildReports.Storage
    Distribution.Client.BuildReports.Types
    Distribution.Client.BuildReports.Upload Distribution.Client.Check
    Distribution.Client.CmdBench Distribution.Client.CmdBuild
    Distribution.Client.CmdClean Distribution.Client.CmdConfigure
    Distribution.Client.CmdErrorMessages Distribution.Client.CmdExec
    Distribution.Client.CmdFreeze Distribution.Client.CmdHaddock
    Distribution.Client.CmdHaddockProject
    Distribution.Client.CmdInstall
    Distribution.Client.CmdInstall.ClientInstallFlags
    Distribution.Client.CmdInstall.ClientInstallTargetSelector
    Distribution.Client.CmdLegacy Distribution.Client.CmdListBin
    Distribution.Client.CmdOutdated Distribution.Client.CmdRepl
    Distribution.Client.CmdRun Distribution.Client.CmdSdist
    Distribution.Client.CmdTest Distribution.Client.CmdUpdate
    Distribution.Client.Compat.Directory
    Distribution.Client.Compat.ExecutablePath
    Distribution.Client.Compat.Orphans
    Distribution.Client.Compat.Prelude
    Distribution.Client.Compat.Semaphore Distribution.Client.Compat.Tar
    Distribution.Client.Config Distribution.Client.Configure
    Distribution.Client.Dependency Distribution.Client.Dependency.Types
    Distribution.Client.DistDirLayout Distribution.Client.Fetch
    Distribution.Client.FetchUtils Distribution.Client.FileMonitor
    Distribution.Client.Freeze Distribution.Client.GZipUtils
    Distribution.Client.GenBounds Distribution.Client.Get
    Distribution.Client.Glob Distribution.Client.GlobalFlags
    Distribution.Client.Haddock Distribution.Client.HashValue
    Distribution.Client.HttpUtils Distribution.Client.IndexUtils
    Distribution.Client.IndexUtils.ActiveRepos
    Distribution.Client.IndexUtils.IndexState
    Distribution.Client.IndexUtils.Timestamp Distribution.Client.Init
    Distribution.Client.Init.Defaults
    Distribution.Client.Init.FileCreators
    Distribution.Client.Init.FlagExtractors
    Distribution.Client.Init.Format
    Distribution.Client.Init.Interactive.Command
    Distribution.Client.Init.Licenses
    Distribution.Client.Init.NonInteractive.Command
    Distribution.Client.Init.NonInteractive.Heuristics
    Distribution.Client.Init.Prompt Distribution.Client.Init.Simple
    Distribution.Client.Init.Types Distribution.Client.Init.Utils
    Distribution.Client.Install Distribution.Client.InstallPlan
    Distribution.Client.InstallSymlink Distribution.Client.JobControl
    Distribution.Client.List Distribution.Client.Main
    Distribution.Client.Manpage Distribution.Client.ManpageFlags
    Distribution.Client.Nix Distribution.Client.NixStyleOptions
    Distribution.Client.PackageHash Distribution.Client.ParseUtils
    Distribution.Client.ProjectBuilding
    Distribution.Client.ProjectBuilding.Types
    Distribution.Client.ProjectConfig
    Distribution.Client.ProjectConfig.Legacy
    Distribution.Client.ProjectConfig.Types
    Distribution.Client.ProjectFlags
    Distribution.Client.ProjectOrchestration
    Distribution.Client.ProjectPlanOutput
    Distribution.Client.ProjectPlanning
    Distribution.Client.ProjectPlanning.Types
    Distribution.Client.RebuildMonad Distribution.Client.Reconfigure
    Distribution.Client.Run Distribution.Client.Sandbox
    Distribution.Client.Sandbox.PackageEnvironment
    Distribution.Client.SavedFlags Distribution.Client.ScriptUtils
    Distribution.Client.Security.DNS Distribution.Client.Security.HTTP
    Distribution.Client.Setup Distribution.Client.SetupWrapper
    Distribution.Client.Signal Distribution.Client.SolverInstallPlan
    Distribution.Client.SourceFiles Distribution.Client.SrcDist
    Distribution.Client.Store Distribution.Client.Tar
    Distribution.Client.TargetProblem
    Distribution.Client.TargetSelector Distribution.Client.Targets
    Distribution.Client.Types Distribution.Client.Types.AllowNewer
    Distribution.Client.Types.BuildResults
    Distribution.Client.Types.ConfiguredId
    Distribution.Client.Types.ConfiguredPackage
    Distribution.Client.Types.Credentials
    Distribution.Client.Types.InstallMethod
    Distribution.Client.Types.OverwritePolicy
    Distribution.Client.Types.PackageLocation
    Distribution.Client.Types.PackageSpecifier
    Distribution.Client.Types.ReadyPackage
    Distribution.Client.Types.Repo Distribution.Client.Types.RepoName
    Distribution.Client.Types.SourcePackageDb
    Distribution.Client.Types.SourceRepo
    Distribution.Client.Types.WriteGhcEnvironmentFilesPolicy
    Distribution.Client.Upload Distribution.Client.Utils
    Distribution.Client.Utils.Json Distribution.Client.Utils.Parsec
    Distribution.Client.VCS Distribution.Client.Version
    Distribution.Client.Win32SelfUpgrade
    Distribution.Deprecated.ParseUtils Distribution.Deprecated.ReadP
    Distribution.Deprecated.ViewAsFieldDescr

hidden-modules:       Paths_cabal_install
import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/cabal-install-3.10.3.0

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/cabal-install-3.10.3.0

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/cabal-install-3.10.3.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cabal-install
hs-libraries:         HScabal-install-3.10.3.0-8vILTNaREgJ9c93t1WS3Ih
depends:
    Cabal-3.10.3.0 Cabal-syntax-3.10.3.0
    HTTP-4000.4.1-6l7hGT0zrEyB2PeNqMvh6F array-0.5.8.0
    async-2.2.5-1ovq96REeQVKYsP5cduurl base-4.18.3.0
    base16-bytestring-1.0.2.0-EknBegOSIL1HpdyXURsRW4 binary-0.8.9.1
    bytestring-0.11.5.4
    cabal-install-solver-3.10.3.0-KPviqxe2CN6E6tVFklqA0z
    containers-0.6.7
    cryptohash-sha256-0.11.102.1-6oFe6jjLSblHef4XZuGQge
    directory-1.3.8.5 echo-0.1.4-5jAiYE5y1Rd5Vq3yZERqaC
    edit-distance-0.2.2.1-8E2Z19UJj3R3ZCLWB4Cyyd exceptions-0.10.7
    filepath-1.4.301.0 hackage-security-0.6.3.2-F35zQTSvZZcGVXEf0cSNSl
    hashable-1.4.7.0-17jkMnZLQLs4o2IKp4JpPo
    lukko-0.1.2-LcMxzRyQaJ08PuHJRIn3rh mtl-2.3.1
    network-uri-2.6.4.2-6QuJNuv1Ns4Gzjjs76diWh parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-GswEfj1SZ276IcAtylwQ0f
    regex-base-0.94.0.3-2nKwTtnMBcoCMKi4tw1MOe
    regex-posix-0.96.0.2-5io6mw87knoCnGAankEkLx
    resolv-0.2.0.3-CUXmr38j5OTBYNO3gBcUZm
    safe-exceptions-0.1.7.4-Ro10nNdK1sGhfCK0np8W0 stm-2.5.1.0
    tar-0.5.1.1-9z7FiTSBOElC7kD8H1QNkl text-2.0.2 time-1.12.2
    unix-2.8.6.0 zlib-0.7.0.0-DS6Da0uFkVx9bSXatFvIRX

haddock-interfaces:   /usr/share/doc/cabal-install/html/cabal-install.haddock
haddock-html:         /usr/share/doc/cabal-install/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
